@@ -9,7 +9,10 @@ class QLCDNumber;
 class QRadioTuner;
 class QToolButton;
 class ClickableImage;
+class EmittingButton;
 class QComboBox;
+class QHBoxLayout;
+class QVBoxLayout;
 
 QT_USE_NAMESPACE
 
@@ -19,39 +22,57 @@ class Radio : public QWidget
 public:
      explicit Radio(QWidget *parent = 0);
     ~Radio();
-    double currentFreq;
-    int currentSet;
-    int currentIndex;
-    int currentFontSize;
-    QFont currentFont;
-    bool restart;
-    QStringList stationsList;
-    QStringList set1List;
-    QStringList set2List;
-    QStringList set3List;
-    QRadioTuner* radio;
+
+    void setStationsListConnection(bool);
+
+    double getFreq();
+    QStringList getSetList(int);
+
+    void setStationsList(QStringList);
+
+    void populateBox(int);
 
 private:
     QLabel* stationName;
     QLabel* rdsData;
     QLabel* signal;
     QLabel *freq;
+
+    EmittingButton *quickAccess[7];
+
+
+
     ClickableImage *leftImage;
     ClickableImage *rightImage;
-    QPushButton* searchLeft;
-    QPushButton* searchRight;
-    QPushButton* nextButton;
+    QPushButton *listButton;
+    QPushButton *prevButton;
+    QPushButton *nextButton;
+    QPushButton *fullScreenButton;
+
+    QStringList stationsList;
+    QStringList set1List;
+    QStringList set2List;
+    QStringList set3List;
+
+    //QuickAccessVariables
+    double quickAccessDouble[7];
+
+    QRadioTuner* radio;
 
     QComboBox *stationsBox;
 
-    void createUI();
+    QHBoxLayout *quickAccessLayout;
+    QVBoxLayout *mainLayout;
+
+    void setLandscapeUI();
+    void setPortraitUI();
+
     void saveSetLists();
-    void loadSetLists();
-
-
-
+    void readSetLists();
 
 signals:
+    void fullScreenButtonClicked();
+    void showStationsDialog();
 
 public slots:
         void freqUp();
@@ -60,26 +81,34 @@ public slots:
         void searchDown();
         void freqChanged(int f);
         void signalChanged(int s);
-        void metaDataChanged();
         void stationPicked(QString);
-        void populateBox();
         void setFreq(int);
         void saveCurrentFreq();
         void loadCurrentFreq();
         void nextButtonClicked();
+        void prevButtonClicked();
         void setLastIndex();
         void restartRadio();
         void readRds();
         void saveCurrentIndex();
         void loadCurrentIndex();
         QFont getFontType();
-        int getFontSize();
-        void changeFont(QFont, int);
-        void saveCurrentFont();
-        void loadCurrentFont();
+        void showFullScreenClicked();
+        void stationsButtonPressed();
+        void quickAccessButtonIsHold(int);
+
+        void readQuickAccess();
+        void saveQuickAccess();
+
+        void showQuickAccess(bool);
+        void setQuickAccess();
+
+        void changeFont(QString, int, int);
+
         void forceMono();
         void forceStereo();
         QStringList getStationsList();
+        void saveSetList(QStringList, int);
 
 
 };
